pub struct RetrievalOrchestrator { /* private fields */ }Expand description
Retrieval pipeline orchestrator.
Coordinates stage execution with:
- Dependency resolution via topological sort
- Parallel execution of independent stages
- Backtracking support for incremental retrieval
- Configurable failure policies
- Pilot integration for intelligent navigation
Example
ⓘ
let orchestrator = RetrievalOrchestrator::new()
.stage(AnalyzeStage::new())
.stage(PlanStage::new())
.stage(SearchStage::new())
.stage(JudgeStage::new())
.with_pilot(pilot)
.with_max_backtracks(3);
let response = orchestrator.execute(tree, query, options).await?;Implementations
Sourceimpl RetrievalOrchestrator
impl RetrievalOrchestrator
Sourcepub fn stage<S>(self, stage: S) -> Selfwhere
S: RetrievalStage + 'static,
pub fn stage<S>(self, stage: S) -> Selfwhere
S: RetrievalStage + 'static,
Add a stage to the pipeline.
Dependencies are read from the stage’s depends_on() method.
Sourcepub fn with_pilot(self, pilot: Arc<dyn Pilot>) -> Self
pub fn with_pilot(self, pilot: Arc<dyn Pilot>) -> Self
Add Pilot for navigation guidance during backtracking.
When set, the Pilot will be consulted during backtracking to provide intelligent guidance on alternative search paths.
Sourcepub fn with_max_backtracks(self, n: usize) -> Self
pub fn with_max_backtracks(self, n: usize) -> Self
Set maximum number of backtracks allowed.
Sourcepub fn with_max_iterations(self, n: usize) -> Self
pub fn with_max_iterations(self, n: usize) -> Self
Set maximum total iterations.
Sourcepub async fn execute(
&mut self,
tree: Arc<DocumentTree>,
query: &str,
options: RetrieveOptions,
) -> Result<RetrieveResponse>
pub async fn execute( &mut self, tree: Arc<DocumentTree>, query: &str, options: RetrieveOptions, ) -> Result<RetrieveResponse>
Execute the retrieval pipeline.
Sourcepub fn stage_names(&self) -> Result<Vec<&str>>
pub fn stage_names(&self) -> Result<Vec<&str>>
Get list of stage names in execution order.
Sourcepub fn get_execution_groups(&self) -> Result<Vec<ExecutionGroup>>
pub fn get_execution_groups(&self) -> Result<Vec<ExecutionGroup>>
Get execution groups for visualization.