pub struct GreedySearch;Expand description
Greedy search - always follows the best single path.
Fast but may miss relevant content in other branches. When a Pilot is provided, it can guide the search at key decision points.
Implementations
Sourceimpl GreedySearch
impl GreedySearch